@@ -17,28 +17,13 @@ class DynamicHelper:
         self.config.read(self.config_file_name, 'utf-8')
         try:
             if self.config.has_section(Elastic.__name__):
-                # if self.config.get(Elastic.__name__, Elastic.HOSTS):
-                #     self.hosts = self.config.get(Elastic.__name__, Elastic.HOSTS)
-                # if self.config.get(Elastic.__name__, Elastic.PORT):
-                #     self.port = self.config.get(Elastic.__name__, Elastic.PORT)
                 if self.config.get(Elastic.__name__, Elastic.INDEX):
                     self.index = self.config.get(Elastic.__name__, Elastic.INDEX)
-                if self.config.get(Elastic.__name__, Elastic.DOC_TYPE):
-                    self.doc_type = self.config.get(Elastic.__name__, Elastic.DOC_TYPE)
         except:
             pass
 
-    # def add_els_config(self, hosts, port, index, doc_type):
-    #     self.hosts = hosts
-    #     self.port = port
-    #     self.index = index
-    #     self.doc_type = doc_type
-
-    def add_els_config(self, index, doc_type):
-        # self.hosts = hosts
-        # self.port = port
+    def add_els_config(self, index):
         self.index = index
-        self.doc_type = doc_type
 
     def create_elastic_mapping(self, arr_fields):
         """
@@ -46,15 +31,9 @@ class DynamicHelper:
         :param arr_fields: list dynamic fields
         :return: elasticsearch mapping string
         """
-
-        # data = {"fields": arr_fields}
-        # self.__validate_create_mapping(data)
         try:
             r = {}
             for field in arr_fields:
-                # field_key = field[DynamicFieldStructure.FIELD_KEY]
-                # field_property = field[DynamicFieldStructure.FIELD_PROPERTY]
-                # display_type = field[DynamicFieldStructure.DISPLAY_TYPE]
 
                 field_validate = FieldValidate(field, -1)
                 r.update(field_validate.create_elastic_mapping())
@@ -64,7 +43,7 @@ class DynamicHelper:
             if es.indices.exists(index=self.index):
                 result = es.indices.put_mapping(
                     index=self.index,
-                    doc_type=self.doc_type,
+                    # doc_type=self.doc_type,
                     body={"properties": r}
                 )
                 return result
