@@ -9,8 +9,10 @@ class ElasticSearchBaseModel:
     _autoid = False
     # _doc_type = sys_conf.get_section_map('Elastic')['doc_type']
     # _index = sys_conf.get_section_map('Elastic')['index']
-
-    _hosts = os.getenv('ELASTIC_SEARCH_HOST').split(',')
+    if os.getenv('ELASTIC_SEARCH_7_HOST'):
+        _hosts = os.getenv('ELASTIC_SEARCH_7_HOST').split(',')
+    else:
+        _hosts = os.getenv('ELASTIC_SEARCH_HOST').split(',')
     _port = os.getenv('ELASTIC_SEARCH_PORT')
     _es_user = os.getenv("ELASTIC_SEARCH_USER", "")
     _es_pass = os.getenv("ELASTIC_SEARCH_PASSWORD", "")
